#!/bin/bash

# The self-consistent file
# this file defines the number of k-points for the density and the plane-wave cutoff
SCF_FILE="hBN.scf.in"
PREFIX="bn"
DYN_FILE="bn.dyn"

# The files for nscf, phonons, and dvscf without the q-points
# in the nscf file we define the number of bands
NSCF_FILE="hBN.nscf.in"
PHONON_FILE="hBN.phonon.in"
DVSCF_FILE="hBN.dvscf.in"

#initial folder
STARTPWD=$PWD

# k-grid for the NSCF calculation
K_GRID_1="12"     # Q-grid use in the nscf
K_GRID_2="12"     # Q-grid use in the nscf
K_GRID_3="1"     # Q-grid use in the nscf
K_GRID="$K_GRID_1 $K_GRID_2 $K_GRID_3"     # Q-grid use in the nscf

# The Q-GRID will be generated starting from the K-GRID

Q_GRID_NAME="QPT12" # Name of the folder where calculations are performed
Q_GRID_FILE="$STARTPWD/my_qgrid" # User defined q-grid, used if Q_GRID_TYPE='file'

echo 
echo " * * * Electron-phonon calculation for Yambo * * * "
echo

#PH and PH run command
echo "Number of processors ${NUM_MPI} "
echo "Number of threads ${OMP_NUM_THREADS}"

NUM_MPI=8
NK=8

MPIRUN="mpirun -np ${NUM_MPI} "
PW_RUN="$MPIRUN /home/attacc/SOFTWARE/qe-7.1/bin/pw.x" 
PH_RUN="$MPIRUN /home/attacc/SOFTWARE/qe-7.1/bin/ph.x "

#Yambo
YAMBO_PATH=/home/attacc/SOFTWARE/yambo-claudio/
YAMBO_PH="$YAMBO_PATH/bin/yambo_ph"
YPP_PH="$YAMBO_PATH/bin/ypp_ph"
P2Y="$YAMBO_PATH/bin/p2y"

echo ""
echo "  * * * Script to generate DVSCF databases * * * "
echo ""
echo "K-grid $K_GRID"
echo "Q-grid folder $Q_GRID_NAME"

# Run the scf
cd scf/
echo "Running SCF ... "
 echo "   Command: $PW_RUN -inp $SCF_FILE > output_scf "
 $PW_RUN -inp $SCF_FILE > output_scf
cd ..

mkdir $Q_GRID_NAME
cd $Q_GRID_NAME

# Run the nscf
mkdir nscf
cd nscf
cat ../../nscf/$NSCF_FILE > $NSCF_FILE
echo "$K_GRID 0 0 0 " >> $NSCF_FILE
cp -r ../../scf/$PREFIX.save ./
echo "Running NSCF ... "
echo "   Command: $PW_RUN -inp $NSCF_FILE > output_nscf "
$PW_RUN -inp $NSCF_FILE > output_nscf 

#Read WF
cd $PREFIX.save
echo "Running P2Y ... "
$P2Y 2> output_p2y
# 
#Yambo setup
echo "setup" > yambo.in_setup
echo "Running YAMBO setup ... "
$YAMBO_PH -noopenmp -nompi -F yambo.in_setup 2> output_setup


#Generate a Q-grid compatible with Yambo
echo "Automatic q-points grid ... "
echo "bzgrids" > ypp.in_qpoints
echo "Q_grid " >> ypp.in_qpoints                        
echo "NoWeights  " >> ypp.in_qpoints
echo "ListPts    " >> ypp.in_qpoints
echo "cooOut= 'alat' "  >>  ypp.in_qpoints
$YPP_PH -noopenmp -nompi -F ypp.in_qpoints 2> output_qpoints
$STARTPWD/get_qlist.py > output_getlist
rm -f $STARTPWD/qpoints
cp qpoints $STARTPWD/
cd $STARTPWD/$Q_GRID_NAME

# Run the phonon
mkdir phonon
cd phonon
cat ../../phonon/$PHONON_FILE > $PHONON_FILE
cat $STARTPWD/qpoints  >> $PHONON_FILE
cp -r ../../scf/$PREFIX.save ./
echo "Running PHONON ... "
$PH_RUN -nk $NK -inp $PHONON_FILE > output_phonon
cd $STARTPWD/$Q_GRID_NAME

# Run the dvscf
mkdir dvscf
cd dvscf
cat ../../dvscf/$DVSCF_FILE > $DVSCF_FILE
cat $STARTPWD/qpoints  >> $DVSCF_FILE
cp -r ../nscf/$PREFIX.save ./
cp -r ../phonon/_ph0 ./ 
cp ../phonon/$DYN_FILE* ./
echo "Running DVSCF ... "
$PH_RUN -nk 1 -inp $DVSCF_FILE > output_dvscf

#Read gkkp matrix elements
cd $PREFIX.save
echo "gkkp"> ypp.in_dbs
echo "gkkp_db" >> ypp.in_dbs
echo 'GkkpExpand' >> ypp.in_dbs
echo 'DBsPATH= "../elph_dir/"' >> ypp.in_dbs
echo "Running YPP_PH gkkp ... "
$YPP_PH -noopenmp -nompi -F ypp.in_dbs 2> output_dbs

cd $STARTPWD
